@@ -1,7 +1,9 @@
 package mapper
 
 import (
+	"crypto/sha1"
 	"fmt"
+	"math"
 	"strings"
 
 	oos "github.com/kubevirt/vm-import-operator/pkg/providers/ovirt/os"
@@ -176,9 +178,6 @@ func (o *OvirtMapper) MapVM(targetVMName *string, vmSpec *kubevirtv1.VirtualMach
 	// Map annotations like sso
 	vmSpec.ObjectMeta.Annotations = o.mapAnnotations()
 
-	// Map placement policy
-	vmSpec.Spec.Template.Spec.EvictionStrategy = o.mapPlacementPolicy()
-
 	// Map timezone
 	vmSpec.Spec.Template.Spec.Domain.Clock = o.mapTimeZone()
 
@@ -227,6 +226,16 @@ func (o *OvirtMapper) MapDisk(vmSpec *kubevirtv1.VirtualMachine, dv cdiv1.DataVo
 	vmSpec.Spec.Template.Spec.Domain.Devices.Disks = append(vmSpec.Spec.Template.Spec.Domain.Devices.Disks, disk)
 }
 
+// RunningState determines whether the created Kubevirt vmSpec should
+// have a running state of true or false.
+func (o *OvirtMapper) RunningState() bool {
+	running := o.mapHighAvailability()
+	if running != nil {
+		return *running
+	}
+	return false
+}
+
 // If the mapping specifies the access mode return that, otherwise determine the access mode
 // of the PVC based on the VM's disk read only attribute and based on the affinity settings of the VM.
 func (o *OvirtMapper) getAccessMode(diskAttachment *ovirtsdk.DiskAttachment, mapping *v2vv1.StorageResourceMappingItem) corev1.PersistentVolumeAccessMode {
@@ -266,8 +275,10 @@ func (o *OvirtMapper) MapDataVolumes(targetVMName *string, filesystemOverhead cd
 
 		diskSize, _ := disk.ProvisionedSize()
 		overhead := utils.GetOverheadForStorageClass(filesystemOverhead, sdClass)
-		sizeWithOverhead := (int64(float64(diskSize) / (1 - overhead)) / 512 + 1) * 512
 
+		blockSize := int64(1048576)
+		alignedSize := utils.RoundUp(diskSize, blockSize)
+		sizeWithOverhead := int64(math.Ceil(float64(alignedSize) / (1 - overhead)))
 		diskSizeConverted, err := utils.FormatBytes(sizeWithOverhead)
 		if err != nil {
 			return dvs, err
@@ -787,7 +798,9 @@ func (o *OvirtMapper) mapFeatures() *kubevirtv1.Features {
 }
 
 func (o *OvirtMapper) mapTimeZone() *kubevirtv1.Clock {
+	clock := kubevirtv1.Clock{Timer: &kubevirtv1.Timer{}}
 	offset := kubevirtv1.ClockOffsetUTC{}
+
 	if tz, ok := o.vm.TimeZone(); ok {
 		if utcOffset, ok := tz.UtcOffset(); ok {
 			parsedOffset, err := utils.ParseUtcOffsetToSeconds(utcOffset)
@@ -796,10 +809,15 @@ func (o *OvirtMapper) mapTimeZone() *kubevirtv1.Clock {
 			} else {
 				log.Info("VM's utc offset is malformed: " + err.Error())
 			}
+		} else if tzName, ok := tz.Name(); ok {
+			timezone := kubevirtv1.ClockOffsetTimezone(tzName)
+			clock.Timezone = &timezone
 		}
 	}
-	clock := kubevirtv1.Clock{Timer: &kubevirtv1.Timer{}}
-	clock.UTC = &offset
+
+	if clock.Timezone == nil {
+		clock.UTC = &offset
+	}
 
 	return &clock
 }
@@ -814,6 +832,7 @@ func getDiskAttachmentByID(id string, diskAttachments *ovirtsdk.DiskAttachmentSl
 }
 
 func buildDataVolumeName(targetVMName string, diskAttachID string) string {
-	dvName, _ := utils.NormalizeName(targetVMName + "-" + diskAttachID)
-	return dvName
+	sha := sha1.New()
+	sha.Write([]byte(targetVMName + diskAttachID))
+	return fmt.Sprintf("%x", sha.Sum(nil))
 }
